{-|
Module      : Gargantext
Description : Textmining Collaborative Platform
Copyright   : (c) CNRS/IMT, 2019-Present
License     : AGPL + CECILL v3
Maintainer  : team@gargantext.org
Stability   : experimental
Portability : POSIX

Examples:
- For a "portrait":
either (\(DecodeFailure e _) -> error $ show e) (length . _docs) <$> get (Just 100) Nothing (Just "anheim_etienne")

- For a "paysage":
either (\(DecodeFailure e _) -> error $ show e) (length . _docs) <$> get (Just 100) (Just "peste noire") Nothing

-}


{-# LANGUAGE OverloadedStrings #-}

module Isidore where

import Isidore.Client
import Network.HTTP.Client (newManager)
import Network.HTTP.Client.TLS (tlsManagerSettings)
import Servant.Client
import Data.Maybe (Maybe)
import Data.Text (Text)
import Data.Either (Either, either)

type Limit = Int
type TextQuery  = Text
type AuthorQuery = Text


getMetadataWith :: Text -> Maybe Int -> IO (Either ClientError Content)
getMetadataWith q l = get l (Just q) Nothing

getMetadataWithAuthor :: Text -> Maybe Int -> IO (Either ClientError Content)
getMetadataWithAuthor q l = get l Nothing (Just q)

get :: Maybe Limit
     -> Maybe TextQuery
     -> Maybe AuthorQuery
     -> IO (Either ClientError Content)
get n q a = do
  manager' <- newManager tlsManagerSettings
  runClientM (clientIsidore n q a)
             (mkClientEnv manager' $ BaseUrl Https "api.isidore.science" 443 "resource")
